@@ -61,11 +61,12 @@ class AlertingProvisioning:
             logging.error("There is no uid defined.")
             raise ValueError
 
-    def add_alert_rule(self, alert_rule: AlertRule):
+    def add_alert_rule(self, alert_rule: AlertRule, disable_provenance: bool = False):
         """The method includes a functionality to create a new alert rule
 
         Args:
             alert_rule (AlertRule): Specify the alert rule
+            disable_provenance (bool): Specify if the provenance header should be set or not (default False)
 
         Raises:
             ValueError: Missed specifying a necessary value
@@ -79,8 +80,9 @@ class AlertingProvisioning:
             api_call: dict = Api(self.grafana_api_model).call_the_api(
                 f"{APIEndpoints.ALERTING_PROVISIONING.value}/alert-rules",
                 RequestsMethods.POST,
-                json.dumps(self.__create_alert_rule_dictionary(alert_rule)),
+                json.dumps(self._create_alert_rule_dictionary(alert_rule)),
                 response_status_code=True,
+                disable_provenance_header=disable_provenance,
             )
 
             if 200 <= api_call.get("status") >= 300:
@@ -92,12 +94,15 @@ class AlertingProvisioning:
             logging.error("There is no alert_rule defined.")
             raise ValueError
 
-    def update_alert_rule(self, uid: str, alert_rule: AlertRule):
+    def update_alert_rule(
+        self, uid: str, alert_rule: AlertRule, disable_provenance: bool = False
+    ):
         """The method includes a functionality to update an existing alert rule
 
         Args:
             uid (str): Specify the alert rule uid
             alert_rule (AlertRule): Specify the alert rule
+            disable_provenance (bool): Specify if the provenance header should be set or not (default False)
 
         Raises:
             ValueError: Missed specifying a necessary value
@@ -111,8 +116,9 @@ class AlertingProvisioning:
             api_call: dict = Api(self.grafana_api_model).call_the_api(
                 f"{APIEndpoints.ALERTING_PROVISIONING.value}/alert-rules/{uid}",
                 RequestsMethods.PUT,
-                json.dumps(self.__create_alert_rule_dictionary(alert_rule)),
+                json.dumps(self._create_alert_rule_dictionary(alert_rule)),
                 response_status_code=True,
+                disable_provenance_header=disable_provenance,
             )
 
             if 200 <= api_call.get("status") >= 300:
@@ -125,7 +131,11 @@ class AlertingProvisioning:
             raise ValueError
 
     def update_the_interval_of_a_alert_rule_group(
-        self, folder_uid: str, group: str, alert_rule_group_interval: int
+        self,
+        folder_uid: str,
+        group: str,
+        alert_rule_group_interval: int,
+        disable_provenance: bool = False,
     ):
         """The method includes a functionality to update the interval of a alert rule group
 
@@ -133,6 +143,7 @@ class AlertingProvisioning:
             folder_uid (str): Specify the folder uid
             group (str): Specify the group
             alert_rule_group_interval (int): Specify the alert rule group interval
+            disable_provenance (bool): Specify if the provenance header should be set or not (default False)
 
         Raises:
             ValueError: Missed specifying a necessary value
@@ -148,6 +159,7 @@ class AlertingProvisioning:
                 RequestsMethods.PUT,
                 json.dumps({"interval": alert_rule_group_interval}),
                 response_status_code=True,
+                disable_provenance_header=disable_provenance,
             )
 
             if 200 <= api_call.get("status") >= 300:
@@ -163,11 +175,12 @@ class AlertingProvisioning:
             )
             raise ValueError
 
-    def delete_alert_rule(self, uid: str):
+    def delete_alert_rule(self, uid: str, disable_provenance: bool = False):
         """The method includes a functionality to delete an alert rule
 
         Args:
             uid (str): Specify the alert rule uid
+            disable_provenance (bool): Specify if the provenance header should be set or not (default False)
 
         Raises:
             ValueError: Missed specifying a necessary value
@@ -181,6 +194,7 @@ class AlertingProvisioning:
                 f"{APIEndpoints.ALERTING_PROVISIONING.value}/alert-rules/{uid}",
                 RequestsMethods.DELETE,
                 response_status_code=True,
+                disable_provenance_header=disable_provenance,
             )
 
             if 200 <= api_call.get("status") >= 300:
@@ -212,11 +226,16 @@ class AlertingProvisioning:
         else:
             return api_call
 
-    def add_contact_point(self, embedded_contact_point: EmbeddedContactPoint):
+    def add_contact_point(
+        self,
+        embedded_contact_point: EmbeddedContactPoint,
+        disable_provenance: bool = False,
+    ):
         """The method includes a functionality to create a contact point
 
         Args:
             embedded_contact_point (EmbeddedContactPoint): Specify the embedded contact point
+            disable_provenance (bool): Specify if the provenance header should be set or not (default False)
 
         Raises:
             ValueError: Missed specifying a necessary value
@@ -241,6 +260,7 @@ class AlertingProvisioning:
                     }
                 ),
                 response_status_code=True,
+                disable_provenance_header=disable_provenance,
             )
 
             if 200 <= api_call.get("status") >= 300:
@@ -253,13 +273,17 @@ class AlertingProvisioning:
             raise ValueError
 
     def update_contact_point(
-        self, uid: str, embedded_contact_point: EmbeddedContactPoint
+        self,
+        uid: str,
+        embedded_contact_point: EmbeddedContactPoint,
+        disable_provenance: bool = False,
     ):
         """The method includes a functionality to update a contact point
 
         Args:
             uid (str): Specify the uid of the contact point
             embedded_contact_point (EmbeddedContactPoint): Specify the embedded contact point
+            disable_provenance (bool): Specify if the provenance header should be set or not (default False)
 
         Raises:
             ValueError: Missed specifying a necessary value
@@ -284,6 +308,7 @@ class AlertingProvisioning:
                     }
                 ),
                 response_status_code=True,
+                disable_provenance_header=disable_provenance,
             )
 
             if 200 <= api_call.get("status") >= 300:
@@ -346,11 +371,12 @@ class AlertingProvisioning:
         else:
             return api_call
 
-    def add_notification_policies(self, route: Route):
+    def add_notification_policies(self, route: Route, disable_provenance: bool = False):
         """The method includes a functionality to set the notification policy tree
 
         Args:
             route (Route): Specify the alert rule routes
+            disable_provenance (bool): Specify if the provenance header should be set or not (default False)
 
         Raises:
             ValueError: Missed specifying a necessary value
@@ -364,8 +390,9 @@ class AlertingProvisioning:
             api_call: dict = Api(self.grafana_api_model).call_the_api(
                 f"{APIEndpoints.ALERTING_PROVISIONING.value}/policies",
                 RequestsMethods.PUT,
-                json.dumps(self.__create_alert_route_dictionary(route)),
+                json.dumps(self._create_alert_route_dictionary(route)),
                 response_status_code=True,
+                disable_provenance_header=disable_provenance,
             )
 
             if 200 <= api_call.get("status") >= 300:
@@ -391,7 +418,7 @@ class AlertingProvisioning:
             f"{APIEndpoints.ALERTING_PROVISIONING.value}/mute-timings",
         )
 
-        if type(api_call) != list:
+        if isinstance(api_call, list) is False:
             logging.error(f"Check the error: {api_call}.")
             raise Exception
         else:
@@ -425,11 +452,14 @@ class AlertingProvisioning:
             logging.error("There is no name defined.")
             raise ValueError
 
-    def add_mute_timing(self, mute_time_interval: MuteTimeInterval):
+    def add_mute_timing(
+        self, mute_time_interval: MuteTimeInterval, disable_provenance: bool = False
+    ):
         """The method includes a functionality to create a mute timing
 
         Args:
             mute_time_interval (MuteTimeInterval): Specify the mute time interval
+            disable_provenance (bool): Specify if the provenance header should be set or not (default False)
 
         Raises:
             ValueError: Missed specifying a necessary value
@@ -443,8 +473,9 @@ class AlertingProvisioning:
             api_call: dict = Api(self.grafana_api_model).call_the_api(
                 f"{APIEndpoints.ALERTING_PROVISIONING.value}/mute-timings",
                 RequestsMethods.POST,
-                json.dumps(self.__create_mute_timing_dictionary(mute_time_interval)),
+                json.dumps(self._create_mute_timing_dictionary(mute_time_interval)),
                 response_status_code=True,
+                disable_provenance_header=disable_provenance,
             )
 
             if 200 <= api_call.get("status") >= 300:
@@ -456,12 +487,18 @@ class AlertingProvisioning:
             logging.error("There is no mute_time_interval defined.")
             raise ValueError
 
-    def update_mute_timing(self, name: str, mute_time_interval: MuteTimeInterval):
+    def update_mute_timing(
+        self,
+        name: str,
+        mute_time_interval: MuteTimeInterval,
+        disable_provenance: bool = False,
+    ):
         """The method includes a functionality to update an existing mute timing
 
         Args:
             name (str): Specify the mute timing name
             mute_time_interval (MuteTimeInterval): Specify the mute time interval
+            disable_provenance (bool): Specify if the provenance header should be set or not (default False)
 
         Raises:
             ValueError: Missed specifying a necessary value
@@ -475,8 +512,9 @@ class AlertingProvisioning:
             api_call: dict = Api(self.grafana_api_model).call_the_api(
                 f"{APIEndpoints.ALERTING_PROVISIONING.value}/mute-timings/{name}",
                 RequestsMethods.PUT,
-                json.dumps(self.__create_mute_timing_dictionary(mute_time_interval)),
+                json.dumps(self._create_mute_timing_dictionary(mute_time_interval)),
                 response_status_code=True,
+                disable_provenance_header=disable_provenance,
             )
 
             if 200 <= api_call.get("status") >= 300:
@@ -532,7 +570,7 @@ class AlertingProvisioning:
             f"{APIEndpoints.ALERTING_PROVISIONING.value}/templates",
         )
 
-        if type(api_call) != list:
+        if isinstance(api_call, list) is False:
             logging.error(f"Check the error: {api_call}.")
             raise Exception
         else:
@@ -567,12 +605,15 @@ class AlertingProvisioning:
             logging.error("There is no name defined.")
             raise ValueError
 
-    def create_or_update_message_template(self, name: str, message_template: str):
+    def create_or_update_message_template(
+        self, name: str, message_template: str, disable_provenance: bool = False
+    ):
         """The method includes a functionality to create or update a message template
 
         Args:
             name (str): Specify the message template name
             message_template (str): Specify the message template
+            disable_provenance (bool): Specify if the provenance header should be set or not (default False)
 
         Raises:
             ValueError: Missed specifying a necessary value
@@ -588,6 +629,7 @@ class AlertingProvisioning:
                 RequestsMethods.PUT,
                 json.dumps({"template": message_template}),
                 response_status_code=True,
+                disable_provenance_header=disable_provenance,
             )
 
             if 200 <= api_call.get("status") >= 300:
@@ -629,7 +671,7 @@ class AlertingProvisioning:
             logging.error("There is no name defined.")
             raise ValueError
 
-    def __create_mute_timing_dictionary(
+    def _create_mute_timing_dictionary(
         self, mute_time_interval: MuteTimeInterval
     ) -> dict:
         """The method includes a functionality to create the mute timing dictionary
@@ -644,13 +686,13 @@ class AlertingProvisioning:
         return dict(
             {
                 "name": mute_time_interval.name,
-                "time_intervals": self.__create_mute_timing_interval_list(
+                "time_intervals": self._create_mute_timing_interval_list(
                     mute_time_interval.time_intervals
                 ),
             }
         )
 
-    def __create_mute_timing_interval_list(
+    def _create_mute_timing_interval_list(
         self, time_intervals: List[TimeInterval]
     ) -> (list, None):
         """The method includes a functionality to create the mute timing interval list
@@ -664,13 +706,13 @@ class AlertingProvisioning:
 
         mute_timing_interval_list: list = list()
 
-        if time_intervals is not None and type(time_intervals) == list:
+        if time_intervals is not None and isinstance(time_intervals, list):
             for time_interval in time_intervals:
                 mute_timing_interval_list.append(
                     {
                         "days_of_month": time_interval.days_of_month,
                         "months": time_interval.months,
-                        "times": self.__create_time_range_list(time_interval.times),
+                        "times": self._create_time_range_list(time_interval.times),
                         "weekdays": time_interval.weekdays,
                         "years": time_interval.years,
                     }
@@ -681,7 +723,7 @@ class AlertingProvisioning:
             return time_intervals
 
     @staticmethod
-    def __create_time_range_list(timing: List[TimeRange]) -> (list, None):
+    def _create_time_range_list(timing: List[TimeRange]) -> (list, None):
         """The method includes a functionality to create the time range list
 
         Args:
@@ -693,7 +735,7 @@ class AlertingProvisioning:
 
         timing_list: list = list()
 
-        if timing is not None and type(timing) == list:
+        if timing is not None and isinstance(timing, list):
             for time in timing:
                 timing_list.append(
                     {"start_time": time.start_time, "end_time": time.end_time}
@@ -703,7 +745,7 @@ class AlertingProvisioning:
         else:
             return timing
 
-    def __create_alert_route_dictionary(self, route: Route) -> dict:
+    def _create_alert_route_dictionary(self, route: Route) -> dict:
         """The method includes a functionality to create the alert route dictionary
 
         Args:
@@ -716,13 +758,13 @@ class AlertingProvisioning:
         return dict(
             {
                 "continue": route.continue_parameter,
-                "groupByStr": route.group_by_str,
-                "muteTimeIntervals": route.mute_time_intervals,
+                "group_by": route.group_by_str,
+                "mute_time_intervals": route.mute_time_intervals,
                 "receiver": route.receiver,
-                "routes": self.__create_alert_routes_list(route.routes),
+                "routes": self._create_alert_routes_list(route.routes),
                 "group_interval": route.group_interval,
                 "group_wait": route.group_wait,
-                "object_matchers": self.__create_object_matcher_list(
+                "object_matchers": self._create_object_matcher_list(
                     route.object_matchers
                 ),
                 "provenance": route.provenance,
@@ -730,7 +772,7 @@ class AlertingProvisioning:
             }
         )
 
-    def __create_alert_routes_list(self, routes: List[Route]) -> (list, None):
+    def _create_alert_routes_list(self, routes: List[Route]) -> (list, None):
         """The method includes a functionality to create the alert route list
 
         Args:
@@ -742,16 +784,16 @@ class AlertingProvisioning:
 
         routes_list: list = list()
 
-        if routes is not None and type(routes) == list:
+        if routes is not None and isinstance(routes, list):
             for route in routes:
-                routes_list.append(self.__create_alert_route_dictionary(route))
+                routes_list.append(self._create_alert_route_dictionary(route))
 
             return routes_list
         else:
             return routes
 
     @staticmethod
-    def __create_object_matcher_list(matchers: List[Matcher]) -> (list, None):
+    def _create_object_matcher_list(matchers: List[Matcher]) -> (list, None):
         """The method includes a functionality to create the object matcher list
 
         Args:
@@ -763,7 +805,7 @@ class AlertingProvisioning:
 
         route_matchers_list: list = list()
 
-        if matchers is not None and type(matchers) == list:
+        if matchers is not None and isinstance(matchers, list):
             for matcher in matchers:
                 route_matcher_dict: dict = dict(
                     {
@@ -779,7 +821,7 @@ class AlertingProvisioning:
         else:
             return matchers
 
-    def __create_alert_rule_dictionary(self, alert_rule: AlertRule) -> dict:
+    def _create_alert_rule_dictionary(self, alert_rule: AlertRule) -> dict:
         """The method includes a functionality to create the alert rule dictionary
 
         Args:
@@ -793,7 +835,7 @@ class AlertingProvisioning:
             {
                 "annotations": alert_rule.annotations,
                 "condition": alert_rule.condition,
-                "data": self.__create_alert_rule_query_list(alert_rule.data),
+                "data": self._create_alert_rule_query_list(alert_rule.data),
                 "execErrState": alert_rule.exec_err_state,
                 "folderUID": alert_rule.folder_uid,
                 "id": alert_rule.id,
@@ -809,7 +851,7 @@ class AlertingProvisioning:
             }
         )
 
-    def __create_alert_rule_query_list(self, alert_queries: List[AlertQuery]) -> list:
+    def _create_alert_rule_query_list(self, alert_queries: List[AlertQuery]) -> list:
         """The method includes a functionality to create the alert rule query list
 
         Args:
@@ -825,7 +867,7 @@ class AlertingProvisioning:
             alert_query_dict: dict = dict(
                 {
                     "datasourceUID": alert_query.datasource_uid,
-                    "model": self.__create_alert_rule_query_model_dictionary(
+                    "model": self._create_alert_rule_query_model_dictionary(
                         alert_query.model
                     ),
                     "queryType": alert_query.query_type,
@@ -841,7 +883,7 @@ class AlertingProvisioning:
 
         return alert_rule_queries_list
 
-    def __create_alert_rule_query_model_dictionary(
+    def _create_alert_rule_query_model_dictionary(
         self, alert_query_model: AlertRuleQueryModel
     ) -> dict:
         """The method includes a functionality to create the alert rule query model dictionary
@@ -855,7 +897,7 @@ class AlertingProvisioning:
 
         return dict(
             {
-                "conditions": self.__create_alert_rule_query_model_condition_list(
+                "conditions": self._create_alert_rule_query_model_condition_list(
                     alert_query_model.conditions
                 ),
                 "datasource": alert_query_model.datasource,
@@ -869,7 +911,7 @@ class AlertingProvisioning:
         )
 
     @staticmethod
-    def __create_alert_rule_query_model_condition_list(
+    def _create_alert_rule_query_model_condition_list(
         alert_rule_query_model_conditions: List[AlertRuleQueryModelCondition],
     ) -> list:
         """The method includes a functionality to create the alert rule query model condition list
