@@ -1,4 +1,5 @@
 import ssl
+import httpx
 from enum import Enum
 from typing import List, TypeVar
 from dataclasses import dataclass, field
@@ -6,7 +7,7 @@ from dataclasses import dataclass, field
 Self = TypeVar("Self", bound="Route")
 
 # The constant includes all necessary error messages that can occurs, if you establish a connection to the Grafana API.
-ERROR_MESSAGES: list = ["invalid API key"]
+ERROR_MESSAGES: list = ["invalid API key", "Invalid API key", "Expired API key"]
 
 
 class APIEndpoints(Enum):
@@ -78,6 +79,7 @@ class APIModel:
         username (str): Specify the username of the Grafana system
         password (str): Specify the password of the Grafana system
         timeout (float): Specify the timeout of the Grafana system
+        http2_support (bool): Specify if you want to use HTTP/2
         ssl_context (ssl.SSLContext): Specify the custom ssl context of the Grafana system
         num_pools (int): Specify the number of the connection pool
         retries (any): Specify the number of the retries. Please use False as parameter to disable the retries
@@ -88,7 +90,8 @@ class APIModel:
     username: str = None
     password: str = None
     timeout: float = 10.0
-    ssl_context: ssl.SSLContext = ssl.create_default_context()
+    http2_support: bool = False
+    ssl_context: ssl.SSLContext = httpx.create_ssl_context(http2=http2_support)
     num_pools: int = 10
     retries: any = 10
 
@@ -712,3 +715,24 @@ class CustomRole:
     group: str = None
     hidden: bool = False
     permissions: List[RolePermission] = None
+
+
+@dataclass
+class DatasourceCache:
+    """The class includes all necessary variables to generate a datasource cache object
+
+    Args:
+        datasource_id (int): Specify the datasource id
+        datasource_uid (str): Specify the datasource uid
+        enabled (bool): Specify if caching should be enabled for the datasource
+        use_default_ttl (bool): Specify if the configured default TTL (Time-To-Live) should be used for both query and resource caching, instead of the user-specified values
+        ttl_queries_ms (int): Specify the TTL to use for query caching, in milliseconds
+        ttl_resources_ms (int): Specify the TTL to use for resource caching, in milliseconds
+    """
+
+    datasource_id: int
+    datasource_uid: str
+    enabled: bool
+    use_default_ttl: bool
+    ttl_queries_ms: int
+    ttl_resources_ms: int
